==> openjdk-src-11.0.1.u13-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sr_Latn_BA.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sr_Latn_BA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BY", "Bjelorusija" },
            { "CG", "Kongo" },
            { "CV", "Kabo Verde" },
            { "CZ", "\u010ce\u0161ka Republika" },
            { "DE", "Njema\u010dka" },
            { "KN", "Sveti Kits i Nevis" },
            { "MO", "SAR Makao" },
            { "PM", "Sveti Pjer i Mikelon" },
            { "RE", "Reunion" },
            { "UM", "Manja udaljena ostrva SAD" },
            { "VC", "Sveti Vinsent i Grenadini" },
            { "VG", "Britanska Djevi\u010danska Ostrva" },
            { "VI", "Ameri\u010dka Djevi\u010danska Ostrva" },
            { "be", "bjeloruski" },
            { "bm", "bamanankan" },
            { "bn", "bangla" },
            { "ht", "hai\u0107anski kreolski" },
            { "lo", "lao\u0161ki" },
            { "si", "sinhalski" },
            { "xh", "isikosa" },
            { "zu", "isizulu" },
            { "arn", "mapudungun" },
            { "gsw", "\u0161vajcarski nema\u010dki" },
            { "moh", "mohok" },
            { "nqo", "n\u2019ko" },
            { "shi", "ju\u017eni \u0161ilha" },
            { "tzm", "centralnoatlaski tama\u0161ek" },
            { "zgh", "standardni marokanski tama\u0161ek" },
        };
        return data;
    }
}

==> openjdk-src-18.0.2.u9-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sr_Latn_BA.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sr_Latn_BA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "svijet" },
            { "003", "Sjevernoameri\u010dki kontinent" },
            { "015", "Sjeverna Afrika" },
            { "019", "Sjeverna i Ju\u017ena Amerika" },
            { "021", "Sjeverna Amerika" },
            { "154", "Sjeverna Evropa" },
            { "AC", "ostrvo Asension" },
            { "BY", "Bjelorusija" },
            { "CC", "Kokosova (Kiling) ostrva" },
            { "CG", "Kongo" },
            { "CP", "ostrvo Kliperton" },
            { "CV", "Kabo Verde" },
            { "CZ", "\u010ce\u0161ka Republika" },
            { "DE", "Njema\u010dka" },
            { "GS", "Ju\u017ena D\u017eord\u017eija i Ju\u017ena Sendvi\u010dka ostrva" },
            { "GU", "Gvam" },
            { "HK", "Hongkong (SAO Kine)" },
            { "HM", "ostrvo Herd i ostrva Makdonald" },
            { "KN", "Sveti Kits i Nevis" },
            { "KP", "Sjeverna Koreja" },
            { "MK", "Sjeverna Makedonija" },
            { "MO", "SAR Makao" },
            { "MP", "Sjeverna Marijanska ostrva" },
            { "NF", "ostrvo Norfok" },
            { "NU", "Nijue" },
            { "PM", "Sveti Pjer i Mikelon" },
            { "PS", "palestinske teritorije" },
            { "RE", "Reunion" },
            { "UM", "Spoljna ostrva SAD" },
            { "VC", "Sveti Vinsent i Grenadini" },
            { "VG", "Britanska Djevi\u010danska Ostrva" },
            { "VI", "Ameri\u010dka Djevi\u010danska Ostrva" },
            { "be", "bjeloruski" },
            { "bm", "bamanankan" },
            { "bn", "bangla" },
            { "de", "njema\u010dki" },
            { "ht", "hai\u0107anski kreolski" },
            { "lo", "lao\u0161ki" },
            { "nd", "sjeverni ndebele" },
            { "se", "sjeverni sami" },
            { "si", "sinhalski" },
            { "xh", "isikosa" },
            { "zu", "isizulu" },
            { "arn", "mapudungun" },
            { "gsw", "njema\u010dki (\u0160vajcarska)" },
            { "lrc", "sjeverni luri" },
            { "moh", "mohok" },
            { "nds", "niskonjema\u010dki" },
            { "nqo", "n\u2019ko" },
            { "shi", "ju\u017eni \u0161ilha" },
            { "tzm", "centralnoatlaski tama\u0161ek" },
            { "zgh", "standardni marokanski tama\u0161ek" },
            { "key.co", "redoslijed sortiranja" },
            { "key.ms", "sistem mjernih jedinica" },
            { "type.nu.mymr", "mjanmarske cifre" },
            { "type.co.ducet", "podrazumijevani Unicode redoslijed sortiranja" },
            { "type.co.search", "pretraga op\u0161te namjene" },
            { "type.co.standard", "standardni redoslijed sortiranja" },
        };
        return data;
    }
}
